@@ -1,5 +1,5 @@
 # prime/prime-japnese.rb: Japanese module for PRIME.
-# $Id: prime-japanese.rb,v 1.2 2004/03/25 17:19:49 komatsu Exp $
+# $Id: prime-japanese.rb,v 1.3 2004/04/04 02:24:47 komatsu Exp $
 #
 # Copyright (C) 2004 Hiroyuki Komatsu <komatsu@taiyaki.org>
 #     All rights reserved.
@@ -33,6 +33,7 @@ module PrimeJapanese
 	'йԸ::', '޹Ը::', 'Ը::',
 	'Ը::', '(Ԥ)::',
 	'ư::', 'ư::', 'ư::'],
+      'ư::' => ['֤::', 'Ǿá֤ʤ::'],
       'ư' => ['Ը', 'Ը', 'Ը', 'Ը', 'ʹԸ', 
 	'йԸ', '޹Ը', 'Ը', 'Ը', '(Ԥ)',
 	'', 'ư'],
@@ -63,7 +64,10 @@ module PrimeJapanese
 
       ## FIXME: ϡֽߡפǤϤʤϢΡ
       ## FIXME: <komatsu@taiyaki.org> (2004-01-19)
-      'ư::'  => ['̾'],
+      'ư::'  => ['̾', '̾'],
+      ## FIXME: ϡֽߡפǤϤʤϢΡ
+      ## FIXME: <komatsu@taiyaki.org> (2004-04-03)
+      'ư::' => ['̾', '̾'],
       'ư::Ϣi' => ['ư'],
       '' => ['ƻ', 'ư', 'ư&̾', 'ư'],
       'ƻ::Ϣ'   => ['̾', '̾&̾', '̾', '̾'],
@@ -78,6 +82,11 @@ module PrimeJapanese
 #      "Ƭ\t̾" => 0.8,
 #      "Ƭ\t()&̾" => 0.8,
 #      "̾\t" => 0.8,
+#      "()::\t̾" => 0.9,
+#      "()::\t̾" => 0.9,
+#      "()::\t̾" => 0.9,
+#      "֤::\t̾" => 0.9,
+#      "Ǿá֤ʤ::\t̾" => 0.9,
       "\t"  => 0.9,
       "̾&̾\t=" => 0.99,
       "̾\t="      => 0.99,
@@ -94,6 +103,7 @@ module PrimeJapanese
     @pos_connection_pos = {
 #      "Ƭ\t̾" => '̾',
 #      "Ƭ\t()&̾" => '()&̾',
+#      "\t̾" => '̾',
       "\t" => '̾',
       "̾\t" => '̾',
       "̾\tư첽" => 'ư',
